look_in
for Windows only, the path to a folder (or vector of
folders) which contains another folder with name containing 'JAGS',
where the JAGS executable(s) are to be found. findjags() will attempt
to find the highest version, assuming that the vers
from.variable
a global variable that may contain the path to
JAGS. This provides a 'set and forget' solution if you have a
non-standard JAGS install, by assigning the variable ".jagspath" (the
default argument value) to the path to JAGS in your R profile file