Learn R Programming

runjags (version 2.0.3-2)

runjags.printmethods: Print methods for runjags helper classes

Description

Print methods for a number of classes that are associated with runjags objects, such as model, data and initial values files etc.

Usage

"print"(x, linenumbers = runjags.getOption("linenumbers"), ...)
"print"(x, linenumbers = runjags.getOption("linenumbers"), ...)
"print"(x, linenumbers = runjags.getOption("linenumbers"), ...)
"print"(x, linenumbers = runjags.getOption("linenumbers"), ...)
"print"(x, linenumbers = runjags.getOption("linenumbers"), ...)
"print"(x, ...)
"print"(x, vars = NA, digits = 5, ...)
"print"(x, vars = NA, digits = 5, ...)
"print"(x, vars = NA, digits = 3, ...)
"print"(x, digits = 3, ...)
"print"(x, ...)
"print"(x, ...)
"summary"(object, ...)
"plot"(x, ...)

Arguments

x
the object to be printed or converted.
linenumbers
option to display line numbers alongside model, data and initial values output (this may be helpful for debugging). Defualt uses the option set in runjags.options.
...
other arguments which are passed to the default print method for some methods but ignored (with/without a warning) for others
vars
an optional character vector of variable names. If supplied, only variable names in the object supplied with a partial match to anything in 'vars' will be used. Note that regular expressions are not allowed, but the caret (^) token can be used to specify the match at the start of a variable name, and a quoted vars will be matched exactly. Default NA meaning all variables available are returned.
digits
the number of digits to display for printed numerical output.
object
the object to be summarised.

See Also

runjags-class for print and plot methods associated with the main runjags class