## Not run:
# # Create a simple linear model and compare the results to LM:
#
# # This is based on the example in ?lm:
# ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
# trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
# group <- gl(2, 10, 20, labels = c("Ctl","Trt"))
# weight <- c(ctl, trt)
# D9 <- data.frame(weight, group)
# lm.D9 <- lm(weight ~ group, data=D9)
#
# # The JAGS equivalent:
# model <- template.jags(weight ~ group, D9, n.chains=2,
# family='gaussian')
# JAGS.D9 <- run.jags(model)
# summary(JAGS.D9)
# summary(lm.D9)
# # Note that lm reports sigma and JAGS the precision - to
# # make them more comparable we could use a mutate function:
# JAGS.D9 <- run.jags(model, mutate=list(prec2sd, 'precision'))
# summary(JAGS.D9)
# summary(lm.D9)
# # Compare the estimated residuals:
# plot(residuals(lm.D9), residuals(JAGS.D9, output='mean'))
#
# # For more examples see:
# vignette('quickjags', package='runjags')
# ## End(Not run)
Run the code above in your browser using DataLab