run.jags, results.jags and autorun.jags, and contain the MCMC chains as well as all information required to extend the simulation. This function allows specific information to be extracted from these functions. For other utility methods for the runjags class, see runjags-class.
"extract"(x, what, force.resample = FALSE, ...)dic.samples) rather than using any statistics that may already be available from the saved runjags objectdic.samplesdic.samples
dic.samples with type="popt"
Note that for the deviance/DIC related parameters, these will be extracted from the available information if possible, or otherwise re-sampled.
runjags-class for additional methods for runjags objects, add.summary for details on plot, print and summary methods for runjags class objects, runjags.options for general options available, and run.jags and autorun.jags for the functions that create objects of this class.