look_in
for Windows only, the path to a folder (or vector of
folders) which contains another folder with name containing 'JAGS',
where the JAGS executable(s) are to be found. findjags() will attempt
to find the highest version, assuming that the version number is
somewhere in the file path to the executable (as per default installation).