run.jags for basic model runsautorun.jags for automated running of models to
convergence and automated calculation of necessary sample sizes
run.jagsfile and autorun.jagsfile for
running of local WinBUGS style text files, as well as methods of
automating retrieval of data and initial values from local text files or
character strings
read.winbugs for translation of WinBUGS text files into
JAGS compatible model, data and initial values files
combine.mcmc and dump.format for MCMC
related tools
timestring, new_unique and ask
for more general tools
xgrid.run.jags and xgrid.submit.jags for use
of Xgrid clusters to run JAGS models remotely
xgrid.run and xgrid.submit for use of Xgrid
clusters for remote execution of user specified R code
jags.model in the rjags package for fine control over the JAGS libraries