Utility function to change the default options for the runjags package.
Options will be used for all runjags function calls for the remainder
of the JAGS session; for a permanent solution consider adding this function
call to your R profile file.
Usage
runjags.options(...)
Arguments
...
named option(s) to change - for a list of available options,
call the function with no parameters.
Value
The current value of all available runjags options (after applying any
changes specified), as a named list.