Utility function to change the default options for the runjags package. Options will be used for all runjags function calls until the runjags package is unloaded. For a permanent solution, create a named list called '.runjags.options' containing the desired options in an R profile file - on loading, runjags will check to see if this object exists in the global environment and set the options automatically.
runjags.options(...)
runjags.getOption(name)
## Not run:
#
# # Create a list of options in the global environment (perhaps in an
# # R startup profile file) BEFORE load()ing runjags:
# .runjags.options <- list(inits.warning=FALSE, rng.warning=FALSE)
# # Or if it is run in a different environment:
# # .runjags.options <<- list(inits.warning=FALSE, rng.warning=FALSE)
#
# # Then load runjags and verify that the options have been set:
# library('runjags')
# print(runjags.options())
#
#
# # Change the default option to remove all feedback provided by
# # runjags and JAGS/rjags (only errors will be printed to screen):
# runjags.options(silent.jags=TRUE, silent.runjags=TRUE)
#
# ## End(Not run)
Run the code above in your browser using DataLab