*Note* Apple has discontinued Xgrid from Mac OS 10.8 onwards, and these functions are deprecated as of runjags version 2.
xgrid.run.jags(model, max.threads=Inf, JAGSversion=">=2.0.0",
email=NA, profiling=TRUE, cpuarch=NA, minosversion=NA,
queueforserver=FALSE, hostnode=NA, forcehost=FALSE,
ramrequired=10, jobname=NA, cleanup=TRUE,
showprofiles=FALSE, jagspath='/usr/local/bin/jags',
mgridpath=system.file("xgrid","mgrid.sh", package="runjags"),
hostname=Sys.getenv("XGRID_CONTROLLER_HOSTNAME"),
password=Sys.getenv("XGRID_CONTROLLER_PASSWORD"), ...)xgrid.autorun.jags(model, max.threads=Inf, JAGSversion=">=2.0.0",
email=NA, profiling=TRUE, cpuarch=NA, minosversion=NA,
queueforserver=FALSE, hostnode=NA, forcehost=FALSE,
ramrequired=10, jobname=NA, cleanup=TRUE,
showprofiles=FALSE, jagspath='/usr/local/bin/jags',
mgridpath=system.file("xgrid","mgrid.sh", package="runjags"),
hostname=Sys.getenv("XGRID_CONTROLLER_HOSTNAME"),
password=Sys.getenv("XGRID_CONTROLLER_PASSWORD"), ...)
xgrid.extend.jags(runjags.object, max.threads=Inf, JAGSversion=">=2.0.0",
email=NA, profiling=TRUE, cpuarch=NA, minosversion=NA,
queueforserver=FALSE, hostnode=NA, forcehost=FALSE,
ramrequired=10, jobname=NA, cleanup=TRUE,
showprofiles=FALSE, jagspath='/usr/local/bin/jags',
mgridpath=system.file("xgrid","mgrid.sh", package="runjags"),
hostname=Sys.getenv("XGRID_CONTROLLER_HOSTNAME"),
password=Sys.getenv("XGRID_CONTROLLER_PASSWORD"), ...)
xgrid.autoextend.jags(runjags.object, max.threads=Inf, JAGSversion=">=2.0.0",
email=NA, profiling=TRUE, cpuarch=NA, minosversion=NA,
queueforserver=FALSE, hostnode=NA, forcehost=FALSE,
ramrequired=10, jobname=NA, cleanup=TRUE,
showprofiles=FALSE, jagspath='/usr/local/bin/jags',
mgridpath=system.file("xgrid","mgrid.sh", package="runjags"),
hostname=Sys.getenv("XGRID_CONTROLLER_HOSTNAME"),
password=Sys.getenv("XGRID_CONTROLLER_PASSWORD"), ...)
xgrid.submit.jags(model, max.threads=Inf, JAGSversion=">=2.0.0",
email=NA, profiling=TRUE, cpuarch=NA, minosversion=NA,
queueforserver=FALSE, hostnode=NA, forcehost=FALSE,
ramrequired=10, jobname=NA, jagspath='/usr/local/bin/jags',
mgridpath=system.file("xgrid", "mgrid.sh", package="runjags"),
hostname=Sys.getenv("XGRID_CONTROLLER_HOSTNAME"),
password=Sys.getenv("XGRID_CONTROLLER_PASSWORD"), ...)
xgrid.results.jags(background.runjags.object, wait=TRUE, cleanup=TRUE)
run.jags function.extend.jags function.run.jags family functions as if the model were being run
locally.run.jags family of functions.The xgrid controller hostname and password can also be set as environmental variables. The command line version of R knows about environmental variables set in the .profile file, but unfortunately the GUI version does not and requires them to be set from within R using:
Sys.setenv(XGRID_CONTROLLER_HOSTNAME="
Sys.setenv(XGRID_CONTROLLER_PASSWORD="
(These lines could be copied into your .Rprofile file for a 'set and forget' solution)
Note that the runjags package also contains a utility shell script called 'mgrid' that enhances the capabilities of Xgrid substantially - to install this from the command line navigate to the folder given by system.file("xgrid", package="runjags") and from the terminal type 'sudo cp mgrid.sh /usr/local/bin/mgrid (or similar) to make the script visible in your search path. Help on the mgrid script can then be obtained by typing 'mgrid' (with no arguments) at the command line.
run.jags, autorun.jags and
runjags-class for more information on JAGS models,
including operations on parallel processorsrun.jags.study for functions to execute JAGS model
validation exercises over parallel processors